def get_page_title(driver: object) -> str:
    return driver.title  # type: ignore
